@@ -1,4 +1,4 @@
-# $Id: ArrayUtil.pm 7785 2013-05-24 03:37:44Z joostvb $
+# $Id: ArrayUtil.pm 8488 2013-11-07 10:07:11Z hurko $
 # $URL: https://pong.uvt.nl/its-nettel/Netwerken/Procedures/libuvt-noc-perl/lib/UvT/NOC/Util/ArrayUtil.pm $
 
 use utf8;
@@ -10,7 +10,7 @@ package UvT::NOC::Util::ArrayUtil;
 use Exporter qw(import);
 use Data::Dumper;
 
-our @EXPORT = qw(uniq remove);
+our @EXPORT = qw(uniq remove containsString);
 our @EXPORT_OK = @EXPORT;
 
 # remove duplicate array entries
@@ -40,4 +40,19 @@ sub remove
 	}
 }
 
+sub containsString
+{
+        my $element = shift;
+        my @array = @_;
+
+        if ( my @found = grep { $_ eq $element } @array )
+        {
+                return 1;
+        }
+        else
+        {
+                return 0;
+        }
+}
+
 1;
